@@ -277,9 +277,9 @@ goa_oauth2_provider_process_redirect_url (GoaOAuth2Provider  *provider,
                                           gchar             **authorization_code,
                                           GError            **error)
 {
-  g_return_val_if_fail (GOA_IS_OAUTH2_PROVIDER (provider), FALSE);
-  g_return_val_if_fail (redirect_url != NULL, FALSE);
-  g_return_val_if_fail (authorization_code != NULL, FALSE);
+  g_return_val_if_fail (GOA_IS_OAUTH2_PROVIDER (provider), NULL);
+  g_return_val_if_fail (redirect_url != NULL, NULL);
+  g_return_val_if_fail (authorization_code != NULL, NULL);
   g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
   return GOA_OAUTH2_PROVIDER_GET_CLASS (provider)->process_redirect_url (provider,
@@ -731,7 +731,6 @@ get_tokens_sync (GoaOAuth2Provider  *provider,
                        GOA_ERROR,
                        GOA_ERROR_FAILED,
                        _("Could not parse response"));
-          g_object_unref (parser);
           goto out;
         }
       /* refresh_token is optional... */
@@ -858,7 +857,7 @@ on_web_view_navigation_policy_decision_requested (WebKitWebView             *web
   const gchar *query;
   const gchar *redirect_uri;
   const gchar *requested_uri;
-  gint response_id;
+  gint response_id = GTK_RESPONSE_NONE;
 
   /* TODO: use oauth2_proxy_extract_access_token() */
 
@@ -964,6 +963,7 @@ on_web_view_navigation_policy_decision_requested (WebKitWebView             *web
   goto ignore_request;
 
  ignore_request:
+  g_assert (response_id != GTK_RESPONSE_NONE);
   gtk_dialog_response (priv->dialog, response_id);
   webkit_web_policy_decision_ignore (policy_decision);
   return TRUE;
